@@ -25,6 +25,7 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
+
 from __future__ import unicode_literals
 
 import logging
@@ -37,6 +38,7 @@ from .features import FeaturesClient
 from .indices import IndicesClient
 from .ingest import IngestClient
 from .nodes import NodesClient
+from .plugins import PluginsClient
 from .remote import RemoteClient
 from .snapshot import SnapshotClient
 from .tasks import TasksClient
@@ -200,6 +202,8 @@ class OpenSearch(object):
 
         self.features = FeaturesClient(self)
 
+        self.plugins = PluginsClient(self)
+
     def __repr__(self):
         try:
             # get a list of all connections
@@ -688,14 +692,15 @@ class OpenSearch(object):
             headers=headers,
         )
 
-    @query_params("master_timeout", "timeout")
+    @query_params("master_timeout", "cluster_manager_timeout", "timeout")
     def delete_script(self, id, params=None, headers=None):
         """
         Deletes a script.
 
 
         :arg id: Script ID
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         """
         if id in SKIP_IN_PATH:
@@ -936,14 +941,15 @@ class OpenSearch(object):
             "GET", _make_path(index, doc_type, id), params=params, headers=headers
         )
 
-    @query_params("master_timeout")
+    @query_params("master_timeout", "cluster_manager_timeout")
     def get_script(self, id, params=None, headers=None):
         """
         Returns a script.
 
 
         :arg id: Script ID
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         """
         if id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'id'.")
@@ -1197,7 +1203,7 @@ class OpenSearch(object):
             "POST", path, params=params, headers=headers, body=body
         )
 
-    @query_params("master_timeout", "timeout")
+    @query_params("master_timeout", "cluster_manager_timeout", "timeout")
     def put_script(self, id, body, context=None, params=None, headers=None):
         """
         Creates or updates a script.
@@ -1206,7 +1212,8 @@ class OpenSearch(object):
         :arg id: Script ID
         :arg body: The document
         :arg context: Context name to compile script against
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         """
         for param in (id, body):
@@ -1574,7 +1581,7 @@ class OpenSearch(object):
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
         :arg local: Return local information, do not retrieve the state
-            from master node (default: false)
+            from cluster_manager node (default: false)
         :arg preference: Specify the node or shard the operation should
             be performed on (default: random)
         :arg routing: Specific routing value
@@ -1947,23 +1954,42 @@ class OpenSearch(object):
         )
 
     @query_params()
-    def close_point_in_time(self, body=None, params=None, headers=None):
+    def list_all_point_in_time(self, params=None, headers=None):
         """
-        Close a point in time
-
-
-        :arg body: a point-in-time id to close
+        Returns the list of active point in times searches
         """
         return self.transport.perform_request(
-            "DELETE", "/_pit", params=params, headers=headers, body=body
+            "GET",
+            _make_path("_search", "point_in_time", "_all"),
+            params=params,
+            headers=headers,
+        )
+
+    @query_params()
+    def delete_point_in_time(self, body=None, all=False, params=None, headers=None):
+        """
+        Delete a point in time
+
+
+        :arg body: a point-in-time id to delete
+        :arg all: set it to `True` to delete all alive point in time.
+        """
+
+        path = (
+            _make_path("_search", "point_in_time", "_all")
+            if all
+            else _make_path("_search", "point_in_time")
+        )
+        return self.transport.perform_request(
+            "DELETE", path, params=params, headers=headers, body=body
         )
 
     @query_params(
         "expand_wildcards", "ignore_unavailable", "keep_alive", "preference", "routing"
     )
-    def open_point_in_time(self, index=None, params=None, headers=None):
+    def create_point_in_time(self, index=None, params=None, headers=None):
         """
-        Open a point in time that can be used in subsequent searches
+        Create a point in time that can be used in subsequent searches
 
 
         :arg index: A comma-separated list of index names to open point
@@ -1980,7 +2006,10 @@ class OpenSearch(object):
         :arg routing: Specific routing value
         """
         return self.transport.perform_request(
-            "POST", _make_path(index, "_pit"), params=params, headers=headers
+            "POST",
+            _make_path(index, "_search", "point_in_time"),
+            params=params,
+            headers=headers,
         )
 
     @query_params()
