@@ -24,6 +24,7 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
+
 from .utils import SKIP_IN_PATH, NamespacedClient, _make_path, query_params
 
 
@@ -104,7 +105,9 @@ class IndicesClient(NamespacedClient):
             "POST", _make_path(index, "_flush"), params=params, headers=headers
         )
 
-    @query_params("master_timeout", "timeout", "wait_for_active_shards")
+    @query_params(
+        "master_timeout", "cluster_manager_timeout", "timeout", "wait_for_active_shards"
+    )
     def create(self, index, body=None, params=None, headers=None):
         """
         Creates an index with optional settings and mappings.
@@ -113,7 +116,8 @@ class IndicesClient(NamespacedClient):
         :arg index: The name of the index
         :arg body: The configuration for the index (`settings` and
             `mappings`)
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         :arg wait_for_active_shards: Set the number of active shards to
             wait for before the operation returns.
@@ -125,7 +129,9 @@ class IndicesClient(NamespacedClient):
             "PUT", _make_path(index), params=params, headers=headers, body=body
         )
 
-    @query_params("master_timeout", "timeout", "wait_for_active_shards")
+    @query_params(
+        "master_timeout", "cluster_manager_timeout", "timeout", "wait_for_active_shards"
+    )
     def clone(self, index, target, body=None, params=None, headers=None):
         """
         Clones an index
@@ -135,7 +141,8 @@ class IndicesClient(NamespacedClient):
         :arg target: The name of the target index to clone into
         :arg body: The configuration for the target index (`settings`
             and `aliases`)
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         :arg wait_for_active_shards: Set the number of active shards to
             wait for on the cloned index before the operation returns.
@@ -160,6 +167,7 @@ class IndicesClient(NamespacedClient):
         "include_defaults",
         "local",
         "master_timeout",
+        "cluster_manager_timeout",
     )
     def get(self, index, params=None, headers=None):
         """
@@ -179,8 +187,9 @@ class IndicesClient(NamespacedClient):
         :arg include_defaults: Whether to return all default setting for
             each of the indices.
         :arg local: Return local information, do not retrieve the state
-            from master node (default: false)
-        :arg master_timeout: Specify timeout for connection to master
+            from cluster_manager node (default: false)
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         """
         if index in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'index'.")
@@ -194,6 +203,7 @@ class IndicesClient(NamespacedClient):
         "expand_wildcards",
         "ignore_unavailable",
         "master_timeout",
+        "cluster_manager_timeout",
         "timeout",
         "wait_for_active_shards",
     )
@@ -211,7 +221,8 @@ class IndicesClient(NamespacedClient):
             closed, hidden, none, all  Default: closed
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         :arg wait_for_active_shards: Sets the number of active shards to
             wait for before the operation returns.
@@ -228,6 +239,7 @@ class IndicesClient(NamespacedClient):
         "expand_wildcards",
         "ignore_unavailable",
         "master_timeout",
+        "cluster_manager_timeout",
         "timeout",
         "wait_for_active_shards",
     )
@@ -245,7 +257,8 @@ class IndicesClient(NamespacedClient):
             closed, hidden, none, all  Default: open
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         :arg wait_for_active_shards: Sets the number of active shards to
             wait for before the operation returns. Set to `index-setting` to wait
@@ -264,6 +277,7 @@ class IndicesClient(NamespacedClient):
         "expand_wildcards",
         "ignore_unavailable",
         "master_timeout",
+        "cluster_manager_timeout",
         "timeout",
     )
     def delete(self, index, params=None, headers=None):
@@ -280,7 +294,8 @@ class IndicesClient(NamespacedClient):
             closed, hidden, none, all  Default: open
         :arg ignore_unavailable: Ignore unavailable indexes (default:
             false)
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         """
         if index in SKIP_IN_PATH:
@@ -316,7 +331,7 @@ class IndicesClient(NamespacedClient):
         :arg include_defaults: Whether to return all default setting for
             each of the indices.
         :arg local: Return local information, do not retrieve the state
-            from master node (default: false)
+            from cluster_manager node (default: false)
         """
         if index in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'index'.")
@@ -330,6 +345,7 @@ class IndicesClient(NamespacedClient):
         "expand_wildcards",
         "ignore_unavailable",
         "master_timeout",
+        "cluster_manager_timeout",
         "timeout",
         "write_index_only",
     )
@@ -350,7 +366,8 @@ class IndicesClient(NamespacedClient):
             closed, hidden, none, all  Default: open
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         :arg write_index_only: When true, applies mappings only to the
             write index of an alias or data stream
@@ -375,6 +392,7 @@ class IndicesClient(NamespacedClient):
         "ignore_unavailable",
         "local",
         "master_timeout",
+        "cluster_manager_timeout",
     )
     def get_mapping(self, index=None, params=None, headers=None):
         """
@@ -391,8 +409,9 @@ class IndicesClient(NamespacedClient):
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
         :arg local: Return local information, do not retrieve the state
-            from master node (default: false)
-        :arg master_timeout: Specify timeout for connection to master
+            from cluster_manager node (default: false)
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         """
         return self.transport.perform_request(
             "GET",
@@ -426,7 +445,7 @@ class IndicesClient(NamespacedClient):
         :arg include_defaults: Whether the default mapping values should
             be returned as well
         :arg local: Return local information, do not retrieve the state
-            from master node (default: false)
+            from cluster_manager node (default: false)
         """
         if fields in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'fields'.")
@@ -438,7 +457,7 @@ class IndicesClient(NamespacedClient):
             headers=headers,
         )
 
-    @query_params("master_timeout", "timeout")
+    @query_params("master_timeout", "cluster_manager_timeout", "timeout")
     def put_alias(self, index, name, body=None, params=None, headers=None):
         """
         Creates or updates an alias.
@@ -450,7 +469,8 @@ class IndicesClient(NamespacedClient):
         :arg name: The name of the alias to be created or updated
         :arg body: The settings for the alias, such as `routing` or
             `filter`
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit timestamp for the document
         """
         for param in (index, name):
@@ -483,7 +503,7 @@ class IndicesClient(NamespacedClient):
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
         :arg local: Return local information, do not retrieve the state
-            from master node (default: false)
+            from cluster_manager node (default: false)
         """
         if name in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'name'.")
@@ -510,20 +530,21 @@ class IndicesClient(NamespacedClient):
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
         :arg local: Return local information, do not retrieve the state
-            from master node (default: false)
+            from cluster_manager node (default: false)
         """
         return self.transport.perform_request(
             "GET", _make_path(index, "_alias", name), params=params, headers=headers
         )
 
-    @query_params("master_timeout", "timeout")
+    @query_params("master_timeout", "cluster_manager_timeout", "timeout")
     def update_aliases(self, body, params=None, headers=None):
         """
         Updates index aliases.
 
 
         :arg body: The definition of `actions` to perform
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Request timeout
         """
         if body in SKIP_IN_PATH:
@@ -533,7 +554,7 @@ class IndicesClient(NamespacedClient):
             "POST", "/_aliases", params=params, headers=headers, body=body
         )
 
-    @query_params("master_timeout", "timeout")
+    @query_params("master_timeout", "cluster_manager_timeout", "timeout")
     def delete_alias(self, index, name, params=None, headers=None):
         """
         Deletes an alias.
@@ -543,7 +564,8 @@ class IndicesClient(NamespacedClient):
             wildcards); use `_all` for all indices
         :arg name: A comma-separated list of aliases to delete (supports
             wildcards); use `_all` to delete all aliases for the specified indices.
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit timestamp for the document
         """
         for param in (index, name):
@@ -554,7 +576,7 @@ class IndicesClient(NamespacedClient):
             "DELETE", _make_path(index, "_alias", name), params=params, headers=headers
         )
 
-    @query_params("create", "master_timeout", "order")
+    @query_params("create", "master_timeout", "cluster_manager_timeout", "order")
     def put_template(self, name, body, params=None, headers=None):
         """
         Creates or updates an index template.
@@ -564,7 +586,8 @@ class IndicesClient(NamespacedClient):
         :arg body: The template definition
         :arg create: Whether the index template should only be added if
             new or can also replace an existing one
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg order: The order for this template when merging multiple
             matching ones (higher numbers are merged later, overriding the lower
             numbers)
@@ -581,7 +604,7 @@ class IndicesClient(NamespacedClient):
             body=body,
         )
 
-    @query_params("flat_settings", "local", "master_timeout")
+    @query_params("flat_settings", "local", "master_timeout", "cluster_manager_timeout")
     def exists_template(self, name, params=None, headers=None):
         """
         Returns information about whether a particular index template exists.
@@ -591,9 +614,11 @@ class IndicesClient(NamespacedClient):
         :arg flat_settings: Return settings in flat format (default:
             false)
         :arg local: Return local information, do not retrieve the state
-            from master node (default: false)
-        :arg master_timeout: Explicit operation timeout for connection
+            from cluster_manager node (default: false)
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Explicit operation timeout for connection
             to master node
+        :arg cluster_manager_timeout: Explicit operation timeout for connection
+            to cluster_manager node
         """
         if name in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'name'.")
@@ -602,7 +627,7 @@ class IndicesClient(NamespacedClient):
             "HEAD", _make_path("_template", name), params=params, headers=headers
         )
 
-    @query_params("flat_settings", "local", "master_timeout")
+    @query_params("flat_settings", "local", "master_timeout", "cluster_manager_timeout")
     def get_template(self, name=None, params=None, headers=None):
         """
         Returns an index template.
@@ -612,22 +637,25 @@ class IndicesClient(NamespacedClient):
         :arg flat_settings: Return settings in flat format (default:
             false)
         :arg local: Return local information, do not retrieve the state
-            from master node (default: false)
-        :arg master_timeout: Explicit operation timeout for connection
+            from cluster_manager node (default: false)
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Explicit operation timeout for connection
             to master node
+        :arg cluster_manager_timeout: Explicit operation timeout for connection
+            to cluster_manager node
         """
         return self.transport.perform_request(
             "GET", _make_path("_template", name), params=params, headers=headers
         )
 
-    @query_params("master_timeout", "timeout")
+    @query_params("master_timeout", "cluster_manager_timeout", "timeout")
     def delete_template(self, name, params=None, headers=None):
         """
         Deletes an index template.
 
 
         :arg name: The name of the template
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         """
         if name in SKIP_IN_PATH:
@@ -645,6 +673,7 @@ class IndicesClient(NamespacedClient):
         "include_defaults",
         "local",
         "master_timeout",
+        "cluster_manager_timeout",
     )
     def get_settings(self, index=None, name=None, params=None, headers=None):
         """
@@ -667,8 +696,9 @@ class IndicesClient(NamespacedClient):
         :arg include_defaults: Whether to return all default setting for
             each of the indices.
         :arg local: Return local information, do not retrieve the state
-            from master node (default: false)
-        :arg master_timeout: Specify timeout for connection to master
+            from cluster_manager node (default: false)
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         """
         return self.transport.perform_request(
             "GET", _make_path(index, "_settings", name), params=params, headers=headers
@@ -680,6 +710,7 @@ class IndicesClient(NamespacedClient):
         "flat_settings",
         "ignore_unavailable",
         "master_timeout",
+        "cluster_manager_timeout",
         "preserve_existing",
         "timeout",
     )
@@ -701,7 +732,8 @@ class IndicesClient(NamespacedClient):
             false)
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg preserve_existing: Whether to update existing settings. If
             set to `true` existing settings on an index remain unchanged, the
             default is `false`
@@ -1040,7 +1072,11 @@ class IndicesClient(NamespacedClient):
         )
 
     @query_params(
-        "copy_settings", "master_timeout", "timeout", "wait_for_active_shards"
+        "copy_settings",
+        "master_timeout",
+        "cluster_manager_timeout",
+        "timeout",
+        "wait_for_active_shards",
     )
     def shrink(self, index, target, body=None, params=None, headers=None):
         """
@@ -1053,7 +1089,8 @@ class IndicesClient(NamespacedClient):
             and `aliases`)
         :arg copy_settings: whether or not to copy settings from the
             source index (defaults to false)
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         :arg wait_for_active_shards: Set the number of active shards to
             wait for on the shrunken index before the operation returns.
@@ -1071,7 +1108,11 @@ class IndicesClient(NamespacedClient):
         )
 
     @query_params(
-        "copy_settings", "master_timeout", "timeout", "wait_for_active_shards"
+        "copy_settings",
+        "master_timeout",
+        "cluster_manager_timeout",
+        "timeout",
+        "wait_for_active_shards",
     )
     def split(self, index, target, body=None, params=None, headers=None):
         """
@@ -1085,7 +1126,8 @@ class IndicesClient(NamespacedClient):
             and `aliases`)
         :arg copy_settings: whether or not to copy settings from the
             source index (defaults to false)
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         :arg wait_for_active_shards: Set the number of active shards to
             wait for on the shrunken index before the operation returns.
@@ -1105,6 +1147,7 @@ class IndicesClient(NamespacedClient):
     @query_params(
         "dry_run",
         "master_timeout",
+        "cluster_manager_timeout",
         "timeout",
         "wait_for_active_shards",
     )
@@ -1121,7 +1164,8 @@ class IndicesClient(NamespacedClient):
         :arg dry_run: If set to true the rollover action will only be
             validated but not actually performed even if a condition matches. The
             default is false
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         :arg wait_for_active_shards: Set the number of active shards to
             wait for on the newly created rollover index before the operation
@@ -1143,6 +1187,7 @@ class IndicesClient(NamespacedClient):
         "expand_wildcards",
         "ignore_unavailable",
         "master_timeout",
+        "cluster_manager_timeout",
         "timeout",
         "wait_for_active_shards",
     )
@@ -1161,7 +1206,8 @@ class IndicesClient(NamespacedClient):
             closed, hidden, none, all  Default: closed
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         :arg wait_for_active_shards: Sets the number of active shards to
             wait for before the operation returns.
@@ -1178,6 +1224,7 @@ class IndicesClient(NamespacedClient):
         "expand_wildcards",
         "ignore_unavailable",
         "master_timeout",
+        "cluster_manager_timeout",
         "timeout",
         "wait_for_active_shards",
     )
@@ -1196,7 +1243,8 @@ class IndicesClient(NamespacedClient):
             closed, hidden, none, all  Default: closed
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         :arg wait_for_active_shards: Sets the number of active shards to
             wait for before the operation returns.
@@ -1269,14 +1317,15 @@ class IndicesClient(NamespacedClient):
             "DELETE", _make_path("_data_stream", name), params=params, headers=headers
         )
 
-    @query_params("master_timeout", "timeout")
+    @query_params("master_timeout", "cluster_manager_timeout", "timeout")
     def delete_index_template(self, name, params=None, headers=None):
         """
         Deletes an index template.
 
 
         :arg name: The name of the template
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         """
         if name in SKIP_IN_PATH:
@@ -1289,7 +1338,7 @@ class IndicesClient(NamespacedClient):
             headers=headers,
         )
 
-    @query_params("flat_settings", "local", "master_timeout")
+    @query_params("flat_settings", "local", "master_timeout", "cluster_manager_timeout")
     def exists_index_template(self, name, params=None, headers=None):
         """
         Returns information about whether a particular index template exists.
@@ -1299,9 +1348,11 @@ class IndicesClient(NamespacedClient):
         :arg flat_settings: Return settings in flat format (default:
             false)
         :arg local: Return local information, do not retrieve the state
-            from master node (default: false)
-        :arg master_timeout: Explicit operation timeout for connection
+            from cluster_manager node (default: false)
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Explicit operation timeout for connection
             to master node
+        :arg cluster_manager_timeout: Explicit operation timeout for connection
+            to cluster_manager node
         """
         if name in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'name'.")
@@ -1310,7 +1361,7 @@ class IndicesClient(NamespacedClient):
             "HEAD", _make_path("_index_template", name), params=params, headers=headers
         )
 
-    @query_params("flat_settings", "local", "master_timeout")
+    @query_params("flat_settings", "local", "master_timeout", "cluster_manager_timeout")
     def get_index_template(self, name=None, params=None, headers=None):
         """
         Returns an index template.
@@ -1320,15 +1371,17 @@ class IndicesClient(NamespacedClient):
         :arg flat_settings: Return settings in flat format (default:
             false)
         :arg local: Return local information, do not retrieve the state
-            from master node (default: false)
-        :arg master_timeout: Explicit operation timeout for connection
+            from cluster_manager node (default: false)
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Explicit operation timeout for connection
             to master node
+        :arg cluster_manager_timeout: Explicit operation timeout for connection
+            to cluster_manager node
         """
         return self.transport.perform_request(
             "GET", _make_path("_index_template", name), params=params, headers=headers
         )
 
-    @query_params("cause", "create", "master_timeout")
+    @query_params("cause", "create", "master_timeout", "cluster_manager_timeout")
     def put_index_template(self, name, body, params=None, headers=None):
         """
         Creates or updates an index template.
@@ -1340,7 +1393,8 @@ class IndicesClient(NamespacedClient):
             template
         :arg create: Whether the index template should only be added if
             new or can also replace an existing one
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         """
         for param in (name, body):
             if param in SKIP_IN_PATH:
@@ -1354,7 +1408,7 @@ class IndicesClient(NamespacedClient):
             body=body,
         )
 
-    @query_params("cause", "create", "master_timeout")
+    @query_params("cause", "create", "master_timeout", "cluster_manager_timeout")
     def simulate_index_template(self, name, body=None, params=None, headers=None):
         """
         Simulate matching the given index name against the index templates in the
@@ -1370,7 +1424,8 @@ class IndicesClient(NamespacedClient):
         :arg create: Whether the index template we optionally defined in
             the body should only be dry-run added if new or can also replace an
             existing one
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         """
         if name in SKIP_IN_PATH:
             raise ValueError("Empty value passed for a required argument 'name'.")
@@ -1399,7 +1454,7 @@ class IndicesClient(NamespacedClient):
             "GET", _make_path("_data_stream", name), params=params, headers=headers
         )
 
-    @query_params("cause", "create", "master_timeout")
+    @query_params("cause", "create", "master_timeout", "cluster_manager_timeout")
     def simulate_template(self, body=None, name=None, params=None, headers=None):
         """
         Simulate resolving the given template name or body
@@ -1413,7 +1468,8 @@ class IndicesClient(NamespacedClient):
         :arg create: Whether the index template we optionally defined in
             the body should only be dry-run added if new or can also replace an
             existing one
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         """
         return self.transport.perform_request(
             "POST",
@@ -1452,6 +1508,7 @@ class IndicesClient(NamespacedClient):
         "expand_wildcards",
         "ignore_unavailable",
         "master_timeout",
+        "cluster_manager_timeout",
         "timeout",
     )
     def add_block(self, index, block, params=None, headers=None):
@@ -1470,7 +1527,8 @@ class IndicesClient(NamespacedClient):
             closed, hidden, none, all  Default: open
         :arg ignore_unavailable: Whether specified concrete indices
             should be ignored when unavailable (missing or closed)
-        :arg master_timeout: Specify timeout for connection to master
+        :arg master_timeout (Deprecated: use cluster_manager_timeout): Specify timeout for connection to master
+        :arg cluster_manager_timeout: Specify timeout for connection to cluster_manager
         :arg timeout: Explicit operation timeout
         """
         for param in (index, block):
